
import * as t from 'babel-types';
import * as babylon from 'babylon';
import traverse from 'babel-traverse';

export default function astify(literal) {
  switch (typeof literal) {
  case 'function':
    try {
      ast = babylon.parse(literal.toString(), {
        allowReturnOutsideFunction: true,
        allowSuperOutsideMethod: true
      });
      return traverse.removeProperties(ast);
    } catch (err) {
      err.stack = `${err.stack}from\n${stack}`;
      throw err;
    }
  case 'number':
    return t.numberLiteral(literal);
  case 'string':
    return t.stringLiteral(literal);
  case 'boolean':
    return t.booleanLiteral(literal);
  case 'null':
    return t.nullLiteral();
  default:
    if (Array.isArray(literal)) {
      return t.arrayExpression(literal.map(astify));
    } else {
      return t.objectExpression(Object.keys(literal)
      .filter(k => {
        return typeof literal[k] !== 'undefined';
      })
      .map(k => {
        return t.objectProperty(
          t.stringLiteral(k),
          astify(literal[k])
        );
      }));
    }
  }
}
